#!/usr/bin/env python

"""
Command utility to examine a SEGY file

     Copyright (C) 2005  Kurt Schwehr

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

$Id: segydump.py,v 1.6 2005/06/03 14:15:20 schwehr Exp $

http://www.python.org/doc/lib/module-optparse.html

"""
import os
import sys

from segy import Segy
import segy

from optparse import OptionParser

# What version do we want to track?  This would be for cvs of this file
vcvs = "$Revision: 1.6 $"
vcvs = vcvs[vcvs.find(':')+2:]
vcvs = vcvs[:vcvs.find('$')-1]
version_cvs = vcvs
del (vcvs) # stop polution

# Track the version of segy-py.  If I use setup.py, which one gets imported?
from segy_version import VERSION

myparser = OptionParser(usage="$prog [options] segyfile1 segyfile2 ... segyfileN",
                      version="%prog "+VERSION+' - '+version_cvs)

myparser.add_option('-d','--driver',dest="drv",
                  help="specify which driver to parse data file.  [default: %default]",
                  default="segy_drv_rev1")
myparser.add_option('-n',"--noFileHeader",action="store_false",dest='fileHeader',
                  help="do not show the file header fields",default=True)
myparser.add_option('-t','--traceHeader',action="store",dest='traceHeaderNumber',
                  help='set this to view values for a trace header [default: %default]',default=None, type='int')
myparser.add_option('-s','--shortList',action="store_true",dest='shortList',default=False,
                  help='restrict the fields to the drivers short list')

print "FIX: make a trace of -1 be all traces!"

if __name__ == '__main__':
    (options,args) = myparser.parse_args()
    #print options
    #print args # Args has the unprocessed arg values ... other files to read
    for filename in args:
        print '\n########################################'
        print 'filename="'+filename+'"'
        print '########################################'
        s = Segy(filename=filename,drivername=options.drv)

        if options.fileHeader:
            print '\n# FILE HEADER'
            s.header.printBinaryHeaders(shortList=options.shortList)

        if options.traceHeaderNumber:
            print '\n# TRACE HEADER',options.traceHeaderNumber
            s.getTraceHdr(options.traceHeaderNumber).printHeader(shortList=options.shortList)
